@@ -36,25 +36,25 @@ func NewCmdIssues(f *cmdutil.Factory, runF func(*shared.IssuesOptions) error) *c
 			<https://docs.github.com/search-github/searching-on-github/searching-issues-and-pull-requests>
 		`),
 		Example: heredoc.Doc(`
-			# search issues matching set of keywords "readme" and "typo"
+			# Search issues matching set of keywords "readme" and "typo"
 			$ gh search issues readme typo
 
-			# search issues matching phrase "broken feature"
+			# Search issues matching phrase "broken feature"
 			$ gh search issues "broken feature"
 
-			# search issues and pull requests in cli organization
+			# Search issues and pull requests in cli organization
 			$ gh search issues --include-prs --owner=cli
 
-			# search open issues assigned to yourself
+			# Search open issues assigned to yourself
 			$ gh search issues --assignee=@me --state=open
 
-			# search issues with numerous comments
+			# Search issues with numerous comments
 			$ gh search issues --comments=">100"
 
-			# search issues without label "bug"
+			# Search issues without label "bug"
 			$ gh search issues -- -label:bug
 
-			# search issues only from un-archived repositories (default is all repositories)
+			# Search issues only from un-archived repositories (default is all repositories)
 			$ gh search issues --owner github --archived=false
 		`),
 		RunE: func(c *cobra.Command, args []string) error {
